==> facebook-common-8.2.0-sources.jar: com/facebook/referrals/ReferralResult.java <==
/*
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.facebook.referrals;

import java.util.Collections;
import java.util.List;

/** This class shows the results of a referral operation. */
public class ReferralResult {
  private final List<String> referralCodes;

  /**
   * The constructor.
   *
   * @param referralCodes The referral codes.
   */
  public ReferralResult(List<String> referralCodes) {
    this.referralCodes = referralCodes;
  }

  /**
   * Getter for the referral codes.
   *
   * @return the referral codes.
   */
  public List<String> getReferralCodes() {
    return Collections.unmodifiableList(referralCodes);
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ReferralResult result = (ReferralResult) o;
    return referralCodes.equals(result.referralCodes);
  }

  @Override
  public int hashCode() {
    return referralCodes.hashCode();
  }
}

==> facebook-common-11.3.0-sources.jar: com/facebook/referrals/ReferralResult.java <==
/*
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * You are hereby granted a non-exclusive, worldwide, royalty-free license to use,
 * copy, modify, and distribute this software in source code or binary form for use
 * in connection with the web services and APIs provided by Facebook.
 *
 * As with any software that integrates with the Facebook platform, your use of
 * this software is subject to the Facebook Developer Principles and Policies
 * [http://developers.facebook.com/policy/]. This copyright notice shall be
 * included in all copies or substantial portions of the software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 * FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 * COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package com.facebook.referrals;

import com.facebook.internal.qualityvalidation.Excuse;
import com.facebook.internal.qualityvalidation.ExcusesForDesignViolations;
import java.util.Collections;
import java.util.List;

/** This class shows the results of a referral operation. */
@ExcusesForDesignViolations(@Excuse(type = "MISSING_UNIT_TEST", reason = "Legacy"))
public class ReferralResult {
  private final List<String> referralCodes;

  /**
   * The constructor.
   *
   * @param referralCodes The referral codes.
   */
  public ReferralResult(List<String> referralCodes) {
    this.referralCodes = referralCodes;
  }

  /**
   * Getter for the referral codes.
   *
   * @return the referral codes.
   */
  public List<String> getReferralCodes() {
    return Collections.unmodifiableList(referralCodes);
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ReferralResult result = (ReferralResult) o;
    return referralCodes.equals(result.referralCodes);
  }

  @Override
  public int hashCode() {
    return referralCodes.hashCode();
  }
}
